#![feature(stdsimd)]
pub mod interface;
pub mod bitboard;
pub mod movegen;
pub mod engine;
pub mod game;
pub mod evaluate;
pub mod search;
pub mod zobrist;
pub mod ttable;
pub mod settings;
pub mod magic;

extern crate log;
extern crate simplelog;
extern crate rand;
extern crate static_assertions;

use std::sync::{mpsc};
use std::{thread, fs::File};
use engine::Engine;
use log::*;
use simplelog::*;
use static_assertions::const_assert_eq;

use crate::movegen::Move;


fn main() {
    /*let mut builder = Builder::from_default_env();
    builder
        .filter(None, LevelFilter::Info)
        .target(Target::Pipe(Box::new(File::create("debug.log").unwrap())))
        //.target(Target::Stderr)
        .init();
        */

    //let logfile = File::create("C:\\Users\\Nicolas\\debug.log").unwrap();
    //simplelog::WriteLogger::init(LevelFilter::Info, Config::default(), logfile).unwrap();
    const_assert_eq!(std::mem::size_of::<Move>(), 4);

    let (esend, erecv) = mpsc::channel();
    let (isend, irecv) = mpsc::channel();

    // spawn engine thread
    thread::spawn(move || {
        let mut engine = Engine::new(erecv, isend);
        engine.run();
    });

    interface::run(irecv, esend);
}


